Class: Genomer::Files
- Inherits:
-
Object
- Object
- Genomer::Files
- Defined in:
- lib/genomer/files.rb
Class Method Summary collapse
Class Method Details
.annotations_gff ⇒ Object
43 44 45 46 47 48 |
# File 'lib/genomer/files.rb', line 43 def annotations_gff <<-EOF.unindent ##gff-version 3 ## Add your gff3 formatted annotations to this file EOF end |
.gemfile ⇒ Object
6 7 8 9 10 11 12 13 |
# File 'lib/genomer/files.rb', line 6 def gemfile version = Genomer::VERSION.split('.')[0..1].<<(0).join('.') <<-EOF.unindent source "https://rubygems.org" gem 'genomer', '~> #{version}' EOF end |
.scaffold_yml ⇒ Object
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/genomer/files.rb', line 15 def scaffold_yml <<-EOF.unindent # Specify your genome scaffold in YAML format here. Reference nucleotide # sequences in the 'sequences.fna' file using the first space delimited # word of each fasta header. # # Go to http://next.gs/getting-started/ to start writing genome scaffold # files. # # A simple one contig example is also provided below. Delete this as you # start writing your own scaffold. --- - sequence: source: "contig1" EOF end |
.sequence_fna ⇒ Object
33 34 35 36 37 38 39 40 41 |
# File 'lib/genomer/files.rb', line 33 def sequence_fna <<-EOF.unindent ; Add your assembled contigs and scaffolds sequences to this file. ; These sequences can be referenced in the 'scaffold.yml' file ; using the first space delimited word in each fasta header. > contig1 ATGC EOF end |